// java wrapper for vtkAlgorithm object
//

package vtk;
import vtk.*;

public class vtkAlgorithm extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int HasExecutive_2();
  public int HasExecutive()
    { return HasExecutive_2(); }

  private native long GetExecutive_3();
  public vtkExecutive GetExecutive() {
    long temp = GetExecutive_3();

    if (temp == 0) return null;
    return (vtkExecutive)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetExecutive_4(vtkExecutive id0);
  public void SetExecutive(vtkExecutive id0)
    { SetExecutive_4(id0); }

  private native int ProcessRequest_5(vtkInformation id0,vtkCollection id1,vtkInformationVector id2);
  public int ProcessRequest(vtkInformation id0,vtkCollection id1,vtkInformationVector id2)
    { return ProcessRequest_5(id0,id1,id2); }

  private native int ModifyRequest_6(vtkInformation id0,int id1);
  public int ModifyRequest(vtkInformation id0,int id1)
    { return ModifyRequest_6(id0,id1); }

  private native long GetInputPortInformation_7(int id0);
  public vtkInformation GetInputPortInformation(int id0) {
    long temp = GetInputPortInformation_7(id0);

    if (temp == 0) return null;
    return (vtkInformation)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetOutputPortInformation_8(int id0);
  public vtkInformation GetOutputPortInformation(int id0) {
    long temp = GetOutputPortInformation_8(id0);

    if (temp == 0) return null;
    return (vtkInformation)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetInformation_9();
  public vtkInformation GetInformation() {
    long temp = GetInformation_9();

    if (temp == 0) return null;
    return (vtkInformation)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetInformation_10(vtkInformation id0);
  public void SetInformation(vtkInformation id0)
    { SetInformation_10(id0); }

  private native int GetNumberOfInputPorts_11();
  public int GetNumberOfInputPorts()
    { return GetNumberOfInputPorts_11(); }

  private native int GetNumberOfOutputPorts_12();
  public int GetNumberOfOutputPorts()
    { return GetNumberOfOutputPorts_12(); }

  private native void Register_13(vtkObjectBase id0);
  public void Register(vtkObjectBase id0)
    { Register_13(id0); }

  private native void UnRegister_14(vtkObjectBase id0);
  public void UnRegister(vtkObjectBase id0)
    { UnRegister_14(id0); }

  private native void SetAbortExecute_15(int id0);
  public void SetAbortExecute(int id0)
    { SetAbortExecute_15(id0); }

  private native int GetAbortExecute_16();
  public int GetAbortExecute()
    { return GetAbortExecute_16(); }

  private native void AbortExecuteOn_17();
  public void AbortExecuteOn()
    { AbortExecuteOn_17(); }

  private native void AbortExecuteOff_18();
  public void AbortExecuteOff()
    { AbortExecuteOff_18(); }

  private native void SetProgress_19(double id0);
  public void SetProgress(double id0)
    { SetProgress_19(id0); }

  private native double GetProgressMinValue_20();
  public double GetProgressMinValue()
    { return GetProgressMinValue_20(); }

  private native double GetProgressMaxValue_21();
  public double GetProgressMaxValue()
    { return GetProgressMaxValue_21(); }

  private native double GetProgress_22();
  public double GetProgress()
    { return GetProgress_22(); }

  private native void UpdateProgress_23(double id0);
  public void UpdateProgress(double id0)
    { UpdateProgress_23(id0); }

  private native void SetProgressText_24(String id0);
  public void SetProgressText(String id0)
    { SetProgressText_24(id0); }

  private native String GetProgressText_25();
  public String GetProgressText()
    { return GetProgressText_25(); }

  private native int GetErrorCode_26();
  public int GetErrorCode()
    { return GetErrorCode_26(); }

  private native long INPUT_IS_OPTIONAL_27();
  public vtkInformationIntegerKey INPUT_IS_OPTIONAL() {
    long temp = INPUT_IS_OPTIONAL_27();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long INPUT_IS_REPEATABLE_28();
  public vtkInformationIntegerKey INPUT_IS_REPEATABLE() {
    long temp = INPUT_IS_REPEATABLE_28();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long INPUT_REQUIRED_FIELDS_29();
  public vtkInformationInformationVectorKey INPUT_REQUIRED_FIELDS() {
    long temp = INPUT_REQUIRED_FIELDS_29();

    if (temp == 0) return null;
    return (vtkInformationInformationVectorKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long INPUT_REQUIRED_DATA_TYPE_30();
  public vtkInformationStringVectorKey INPUT_REQUIRED_DATA_TYPE() {
    long temp = INPUT_REQUIRED_DATA_TYPE_30();

    if (temp == 0) return null;
    return (vtkInformationStringVectorKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long INPUT_ARRAYS_TO_PROCESS_31();
  public vtkInformationInformationVectorKey INPUT_ARRAYS_TO_PROCESS() {
    long temp = INPUT_ARRAYS_TO_PROCESS_31();

    if (temp == 0) return null;
    return (vtkInformationInformationVectorKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long INPUT_PORT_32();
  public vtkInformationIntegerKey INPUT_PORT() {
    long temp = INPUT_PORT_32();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long INPUT_CONNECTION_33();
  public vtkInformationIntegerKey INPUT_CONNECTION() {
    long temp = INPUT_CONNECTION_33();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long CAN_PRODUCE_SUB_EXTENT_34();
  public vtkInformationIntegerKey CAN_PRODUCE_SUB_EXTENT() {
    long temp = CAN_PRODUCE_SUB_EXTENT_34();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long CAN_HANDLE_PIECE_REQUEST_35();
  public vtkInformationIntegerKey CAN_HANDLE_PIECE_REQUEST() {
    long temp = CAN_HANDLE_PIECE_REQUEST_35();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetInputArrayToProcess_36(int id0,int id1,int id2,int id3,String id4);
  public void SetInputArrayToProcess(int id0,int id1,int id2,int id3,String id4)
    { SetInputArrayToProcess_36(id0,id1,id2,id3,id4); }

  private native void SetInputArrayToProcess_37(int id0,int id1,int id2,int id3,int id4);
  public void SetInputArrayToProcess(int id0,int id1,int id2,int id3,int id4)
    { SetInputArrayToProcess_37(id0,id1,id2,id3,id4); }

  private native void SetInputArrayToProcess_38(int id0,vtkInformation id1);
  public void SetInputArrayToProcess(int id0,vtkInformation id1)
    { SetInputArrayToProcess_38(id0,id1); }

  private native void SetInputArrayToProcess_39(int id0,int id1,int id2,String id3,String id4);
  public void SetInputArrayToProcess(int id0,int id1,int id2,String id3,String id4)
    { SetInputArrayToProcess_39(id0,id1,id2,id3,id4); }

  private native long GetInputArrayInformation_40(int id0);
  public vtkInformation GetInputArrayInformation(int id0) {
    long temp = GetInputArrayInformation_40(id0);

    if (temp == 0) return null;
    return (vtkInformation)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void RemoveAllInputs_41();
  public void RemoveAllInputs()
    { RemoveAllInputs_41(); }

  private native long GetOutputDataObject_42(int id0);
  public vtkDataObject GetOutputDataObject(int id0) {
    long temp = GetOutputDataObject_42(id0);

    if (temp == 0) return null;
    return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetInputDataObject_43(int id0,int id1);
  public vtkDataObject GetInputDataObject(int id0,int id1) {
    long temp = GetInputDataObject_43(id0,id1);

    if (temp == 0) return null;
    return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetInputConnection_44(int id0,vtkAlgorithmOutput id1);
  public void SetInputConnection(int id0,vtkAlgorithmOutput id1)
    { SetInputConnection_44(id0,id1); }

  private native void SetInputConnection_45(vtkAlgorithmOutput id0);
  public void SetInputConnection(vtkAlgorithmOutput id0)
    { SetInputConnection_45(id0); }

  private native void AddInputConnection_46(int id0,vtkAlgorithmOutput id1);
  public void AddInputConnection(int id0,vtkAlgorithmOutput id1)
    { AddInputConnection_46(id0,id1); }

  private native void AddInputConnection_47(vtkAlgorithmOutput id0);
  public void AddInputConnection(vtkAlgorithmOutput id0)
    { AddInputConnection_47(id0); }

  private native void RemoveInputConnection_48(int id0,vtkAlgorithmOutput id1);
  public void RemoveInputConnection(int id0,vtkAlgorithmOutput id1)
    { RemoveInputConnection_48(id0,id1); }

  private native void RemoveInputConnection_49(int id0,int id1);
  public void RemoveInputConnection(int id0,int id1)
    { RemoveInputConnection_49(id0,id1); }

  private native void RemoveAllInputConnections_50(int id0);
  public void RemoveAllInputConnections(int id0)
    { RemoveAllInputConnections_50(id0); }

  private native void SetInputDataObject_51(int id0,vtkDataObject id1);
  public void SetInputDataObject(int id0,vtkDataObject id1)
    { SetInputDataObject_51(id0,id1); }

  private native void SetInputDataObject_52(vtkDataObject id0);
  public void SetInputDataObject(vtkDataObject id0)
    { SetInputDataObject_52(id0); }

  private native void AddInputDataObject_53(int id0,vtkDataObject id1);
  public void AddInputDataObject(int id0,vtkDataObject id1)
    { AddInputDataObject_53(id0,id1); }

  private native void AddInputDataObject_54(vtkDataObject id0);
  public void AddInputDataObject(vtkDataObject id0)
    { AddInputDataObject_54(id0); }

  private native long GetOutputPort_55(int id0);
  public vtkAlgorithmOutput GetOutputPort(int id0) {
    long temp = GetOutputPort_55(id0);

    if (temp == 0) return null;
    return (vtkAlgorithmOutput)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetOutputPort_56();
  public vtkAlgorithmOutput GetOutputPort() {
    long temp = GetOutputPort_56();

    if (temp == 0) return null;
    return (vtkAlgorithmOutput)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetNumberOfInputConnections_57(int id0);
  public int GetNumberOfInputConnections(int id0)
    { return GetNumberOfInputConnections_57(id0); }

  private native int GetTotalNumberOfInputConnections_58();
  public int GetTotalNumberOfInputConnections()
    { return GetTotalNumberOfInputConnections_58(); }

  private native long GetInputConnection_59(int id0,int id1);
  public vtkAlgorithmOutput GetInputConnection(int id0,int id1) {
    long temp = GetInputConnection_59(id0,id1);

    if (temp == 0) return null;
    return (vtkAlgorithmOutput)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetInputAlgorithm_60(int id0,int id1);
  public vtkAlgorithm GetInputAlgorithm(int id0,int id1) {
    long temp = GetInputAlgorithm_60(id0,id1);

    if (temp == 0) return null;
    return (vtkAlgorithm)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetInputAlgorithm_61();
  public vtkAlgorithm GetInputAlgorithm() {
    long temp = GetInputAlgorithm_61();

    if (temp == 0) return null;
    return (vtkAlgorithm)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetInputExecutive_62(int id0,int id1);
  public vtkExecutive GetInputExecutive(int id0,int id1) {
    long temp = GetInputExecutive_62(id0,id1);

    if (temp == 0) return null;
    return (vtkExecutive)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetInputExecutive_63();
  public vtkExecutive GetInputExecutive() {
    long temp = GetInputExecutive_63();

    if (temp == 0) return null;
    return (vtkExecutive)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetInputInformation_64(int id0,int id1);
  public vtkInformation GetInputInformation(int id0,int id1) {
    long temp = GetInputInformation_64(id0,id1);

    if (temp == 0) return null;
    return (vtkInformation)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetInputInformation_65();
  public vtkInformation GetInputInformation() {
    long temp = GetInputInformation_65();

    if (temp == 0) return null;
    return (vtkInformation)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetOutputInformation_66(int id0);
  public vtkInformation GetOutputInformation(int id0) {
    long temp = GetOutputInformation_66(id0);

    if (temp == 0) return null;
    return (vtkInformation)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void Update_67(int id0);
  public void Update(int id0)
    { Update_67(id0); }

  private native void Update_68();
  public void Update()
    { Update_68(); }

  private native int Update_69(int id0,vtkInformationVector id1);
  public int Update(int id0,vtkInformationVector id1)
    { return Update_69(id0,id1); }

  private native int Update_70(vtkInformation id0);
  public int Update(vtkInformation id0)
    { return Update_70(id0); }

  private native int UpdatePiece_71(int id0,int id1,int id2,int id3[]);
  public int UpdatePiece(int id0,int id1,int id2,int id3[])
    { return UpdatePiece_71(id0,id1,id2,id3); }

  private native int UpdateExtent_72(int id0[]);
  public int UpdateExtent(int id0[])
    { return UpdateExtent_72(id0); }

  private native int UpdateTimeStep_73(double id0,int id1,int id2,int id3,int id4[]);
  public int UpdateTimeStep(double id0,int id1,int id2,int id3,int id4[])
    { return UpdateTimeStep_73(id0,id1,id2,id3,id4); }

  private native void UpdateInformation_74();
  public void UpdateInformation()
    { UpdateInformation_74(); }

  private native void UpdateDataObject_75();
  public void UpdateDataObject()
    { UpdateDataObject_75(); }

  private native void PropagateUpdateExtent_76();
  public void PropagateUpdateExtent()
    { PropagateUpdateExtent_76(); }

  private native void UpdateWholeExtent_77();
  public void UpdateWholeExtent()
    { UpdateWholeExtent_77(); }

  private native void SetReleaseDataFlag_78(int id0);
  public void SetReleaseDataFlag(int id0)
    { SetReleaseDataFlag_78(id0); }

  private native int GetReleaseDataFlag_79();
  public int GetReleaseDataFlag()
    { return GetReleaseDataFlag_79(); }

  private native void ReleaseDataFlagOn_80();
  public void ReleaseDataFlagOn()
    { ReleaseDataFlagOn_80(); }

  private native void ReleaseDataFlagOff_81();
  public void ReleaseDataFlagOff()
    { ReleaseDataFlagOff_81(); }

  private native int UpdateExtentIsEmpty_82(vtkInformation id0,vtkDataObject id1);
  public int UpdateExtentIsEmpty(vtkInformation id0,vtkDataObject id1)
    { return UpdateExtentIsEmpty_82(id0,id1); }

  private native int UpdateExtentIsEmpty_83(vtkInformation id0,int id1);
  public int UpdateExtentIsEmpty(vtkInformation id0,int id1)
    { return UpdateExtentIsEmpty_83(id0,id1); }

  private native void SetDefaultExecutivePrototype_84(vtkExecutive id0);
  public void SetDefaultExecutivePrototype(vtkExecutive id0)
    { SetDefaultExecutivePrototype_84(id0); }

  private native int SetUpdateExtentToWholeExtent_85(int id0);
  public int SetUpdateExtentToWholeExtent(int id0)
    { return SetUpdateExtentToWholeExtent_85(id0); }

  private native int SetUpdateExtentToWholeExtent_86();
  public int SetUpdateExtentToWholeExtent()
    { return SetUpdateExtentToWholeExtent_86(); }

  private native void SetUpdateExtent_87(int id0,int id1,int id2,int id3);
  public void SetUpdateExtent(int id0,int id1,int id2,int id3)
    { SetUpdateExtent_87(id0,id1,id2,id3); }

  private native void SetUpdateExtent_88(int id0,int id1,int id2);
  public void SetUpdateExtent(int id0,int id1,int id2)
    { SetUpdateExtent_88(id0,id1,id2); }

  private native void SetUpdateExtent_89(int id0,int id1[]);
  public void SetUpdateExtent(int id0,int id1[])
    { SetUpdateExtent_89(id0,id1); }

  private native void SetUpdateExtent_90(int id0[]);
  public void SetUpdateExtent(int id0[])
    { SetUpdateExtent_90(id0); }

  private native int[]  GetUpdateExtent_91();
  public int[]  GetUpdateExtent()
    { return GetUpdateExtent_91(); }

  private native int[]  GetUpdateExtent_92(int id0);
  public int[]  GetUpdateExtent(int id0)
    { return GetUpdateExtent_92(id0); }

  private native void GetUpdateExtent_93(int id0[]);
  public void GetUpdateExtent(int id0[])
    { GetUpdateExtent_93(id0); }

  private native void GetUpdateExtent_94(int id0,int id1[]);
  public void GetUpdateExtent(int id0,int id1[])
    { GetUpdateExtent_94(id0,id1); }

  private native int GetUpdatePiece_95();
  public int GetUpdatePiece()
    { return GetUpdatePiece_95(); }

  private native int GetUpdatePiece_96(int id0);
  public int GetUpdatePiece(int id0)
    { return GetUpdatePiece_96(id0); }

  private native int GetUpdateNumberOfPieces_97();
  public int GetUpdateNumberOfPieces()
    { return GetUpdateNumberOfPieces_97(); }

  private native int GetUpdateNumberOfPieces_98(int id0);
  public int GetUpdateNumberOfPieces(int id0)
    { return GetUpdateNumberOfPieces_98(id0); }

  private native int GetUpdateGhostLevel_99();
  public int GetUpdateGhostLevel()
    { return GetUpdateGhostLevel_99(); }

  private native int GetUpdateGhostLevel_100(int id0);
  public int GetUpdateGhostLevel(int id0)
    { return GetUpdateGhostLevel_100(id0); }

  private native void SetProgressObserver_101(vtkProgressObserver id0);
  public void SetProgressObserver(vtkProgressObserver id0)
    { SetProgressObserver_101(id0); }

  private native long GetProgressObserver_102();
  public vtkProgressObserver GetProgressObserver() {
    long temp = GetProgressObserver_102();

    if (temp == 0) return null;
    return (vtkProgressObserver)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkAlgorithm() { super(); }

  public vtkAlgorithm(long id) { super(id); }
  public native long   VTKInit();

}
